@@ -14,16 +14,12 @@
 import io
 import math
 import os
-from pathlib import Path
 from typing import Callable, Dict, Iterable, List, Optional, Union
 
 import braceexpand
-import librosa
 import numpy as np
 import torch
 import webdataset as wd
-from scipy.stats import betabinom
-from torch.nn import functional as F
 from torch.utils.data import ChainDataset
 
 from nemo.collections.asr.parts.preprocessing.features import WaveformFeaturizer
@@ -31,14 +27,10 @@ from nemo.collections.common import tokenizers
 from nemo.collections.common.parts.preprocessing import collections, parsers
 from nemo.core.classes import Dataset, IterableDataset
 from nemo.core.neural_types import *
-from nemo.core.neural_types.elements import ProbsType
 from nemo.utils import logging
-from nemo.utils.decorators import deprecated
 
 __all__ = [
     'AudioToCharDataset',
-    'AudioToCharWithDursF0Dataset',
-    'AudioToCharWithPriorDataset',
     'AudioToBPEDataset',
     'TarredAudioToCharDataset',
     'TarredAudioToBPEDataset',
@@ -402,471 +394,6 @@ class AudioToCharDataset(_AudioTextDataset):
         )
 
 
-@deprecated(version="1.8", explanation="Please, use ``nemo.tts.collections.torch.data.TTSDataset`` instead.")
-class AudioToCharWithDursF0Dataset(AudioToCharDataset):
-    """
-    Dataset that loads tensors via a json file containing paths to audio
-    files, transcripts, and durations (in seconds).
-    Each new line is a different sample. Example below:
-    {"audio_filepath": "/path/to/audio_1.wav", "text": "the
-    transcription", "offset": 301.75, "duration": 0.82}
-    ...
-    {"audio_filepath": "/path/to/audio_n.wav", "text": "the
-    transcription", "offset": 301.75, "duration": 0.82}
-
-    Additionally, user provides path to precomputed durations via "durs_file" arg, which is a pickled python dict,
-    mapping example tag to it's durations tensor, and name of method that was received durations via "durs_type".
-    Tag is a unique example identifier, which is a wav filename without suffix. Durations depend on "durs_type".
-    If durs_type == "asr_based" then durations are an additional dict of two tensors: graphemes/phonemes durations and blanks durations with
-    "blanks" and "tokens" keys respectively.
-    Example below:
-    {'LJ050-0234': {'blanks': `blanks_durs_tensor`, 'tokens': `tokens_durs_tensor`},
-    ...}
-    If durs_type == "aligner_based" then durations are just tensor graphemes/phonemes durations.
-    Example below:
-    {'LJ050-0234': `tokens_durs_tensor`},
-    ...}
-
-    Additionally, F0 statistics is passed precomputed along mel length via "f0_file" arg, which is a pickled python
-    dict, mapping example tag to it's f0 tensor.
-    Example below:
-    {'LJ050-0234': `f0_tensor`,
-    ...}
-
-    Args:
-        **kwargs: Passed to AudioToCharDataset constructor.
-        durs_file (str): String path to pickled durations location.
-        durs_type (str): Type of durations. Currently supported durations are "asr-based" and "aligned-based".
-        f0_file (str): String path to pickled f0 statistics location.
-        blanking (bool): Boolean flag indicate whether add or not blanks between text graphemes.
-        load_audio(bool): Boolean flag indicate whether do or not load audio.
-        vocab: Vocabulary config (parser + set of graphemes to use). Constructor propagates these to
-            `self.make_vocab` function call to build a complete vocabulary.
-    """
-
-    @property
-    def output_types(self) -> Optional[Dict[str, NeuralType]]:
-        """Returns definitions of module output ports."""
-        return {
-            'audio': NeuralType(('B', 'T'), AudioSignal()),
-            'audio_len': NeuralType(('B',), LengthsType()),
-            'text': NeuralType(('B', 'T'), LabelsType()),
-            'text_len': NeuralType(('B',), LengthsType()),
-            'durs': NeuralType(('B', 'T'), LengthsType()),
-            'f0': NeuralType(('B', 'T'), FloatType()),
-            'f0_mask': NeuralType(('B', 'T'), MaskType()),
-        }
-
-    @staticmethod
-    def make_vocab(
-        notation='chars',
-        punct=True,
-        spaces=False,
-        stresses=False,
-        chars=False,
-        add_blank_at="last_but_one",
-        pad_with_space=False,
-        improved_version_g2p=False,
-        phoneme_dict_path=None,
-    ):
-        """Constructs vocabulary from given parameters.
-
-        Args:
-            notation (str): Either 'chars' or 'phonemes' as general notation.
-            punct (bool): True if reserve grapheme for basic punctuation.
-            spaces (bool): True if prepend spaces to every punctuation symbol.
-            stresses (bool): True if use phonemes codes with stresses (0-2).
-            chars (bool): True if additionally use chars together with phonemes.
-            add_blank_at: add blank to labels in the specified order ("last" or "last_but_one"),
-             if None then no blank in labels.
-            pad_with_space (bool): True if pad text with spaces at the beginning and at the end.
-            improved_version_g2p (bool): True if use new version of g2p.
-            phoneme_dict_path (str): path to phoneme dict file (like CMU Pronouncing dictionary). If it's None then cmudict.dict() will be used.
-
-        Returns:
-            (vocabs.Base) Vocabulary
-        """
-        from nemo.collections.common.data import vocabs
-
-        if notation == 'chars':
-            vocab = vocabs.Chars(punct=punct, spaces=spaces, add_blank_at=add_blank_at)
-        elif notation == 'phonemes':
-            vocab = vocabs.Phonemes(
-                punct=punct,
-                stresses=stresses,
-                spaces=spaces,
-                chars=chars,
-                add_blank_at=add_blank_at,
-                pad_with_space=pad_with_space,
-                improved_version_g2p=improved_version_g2p,
-                phoneme_dict_path=phoneme_dict_path,
-            )
-        else:
-            raise ValueError("Unsupported vocab type.")
-        return vocab
-
-    def __init__(self, **kwargs):
-        durs_file = kwargs.pop('durs_file', None)
-        durs_type = kwargs.pop('durs_type', "asr-based")
-        f0_file = kwargs.pop('f0_file', None)
-        self.blanking = kwargs.pop('blanking', False)
-        self.load_audio = kwargs.pop('load_audio', True)
-        self.vocab = self.make_vocab(**kwargs.pop('vocab', {}))
-        kwargs.setdefault('labels', [])  # For compatibility.
-        super().__init__(**kwargs)
-
-        tags = []
-        self.id2enc_text = {}
-        for i, e in enumerate(self.manifest_processor.collection):
-            tag = os.path.splitext(os.path.basename(e.audio_file))[0]
-            tags.append(tag)
-            # cache vocab encoding
-            self.id2enc_text[i] = self.vocab.encode(e.text_raw)
-
-        if durs_file:
-            tag2durs = torch.load(durs_file)
-            durs = []
-            for tag in tags:
-                tag_durs = tag2durs[tag]
-                if durs_type == "asr-based":
-                    durs.append(self.interleave(tag_durs['blanks'], tag_durs['tokens']))
-                elif durs_type == "aligner-based":
-                    durs.append(tag_durs)
-                else:
-                    raise NotImplementedError(
-                        f"{durs_type} duration type is not supported. Use asr-based or align-based."
-                    )
-            self.durs = durs
-        if f0_file:
-            tag2f0 = torch.load(f0_file)
-            self.f0 = [tag2f0[tag] for tag in tags]
-
-    def __getitem__(self, item):
-        audio, audio_len = None, None
-        if self.load_audio:
-            audio, audio_len, _, _ = super().__getitem__(item)  # noqa
-
-        text = self.id2enc_text[item]
-        text, text_len = torch.tensor(text).long(), torch.tensor(len(text)).long()
-        durs, f0 = self.durs[item], self.f0[item]
-        return (
-            audio,
-            audio_len,
-            text,
-            text_len,
-            durs,
-            f0,
-        )
-
-    @staticmethod
-    def merge(tensors, dim=0, value=0, dtype=None):
-        """Merges list of tensors into one."""
-        tensors = [tensor if isinstance(tensor, torch.Tensor) else torch.tensor(tensor) for tensor in tensors]
-        dim = dim if dim != -1 else len(tensors[0].shape) - 1
-        dtype = tensors[0].dtype if dtype is None else dtype
-        max_len = max(tensor.shape[dim] for tensor in tensors)
-        new_tensors = []
-        for tensor in tensors:
-            pad = (2 * len(tensor.shape)) * [0]
-            pad[-2 * dim - 1] = max_len - tensor.shape[dim]
-            new_tensors.append(F.pad(tensor, pad=pad, value=value))
-        return torch.stack(new_tensors).to(dtype=dtype)
-
-    @classmethod
-    def repeat_merge(cls, x, reps, pad):
-        """Repeats `x` values according to `reps` tensor and merges."""
-        return cls.merge(
-            tensors=[torch.repeat_interleave(text1, durs1) for text1, durs1 in zip(x, reps)], value=pad, dtype=x.dtype,
-        )
-
-    @staticmethod
-    def make_mask(lengths, max_length=None):
-        """Makes mask from list of lengths."""
-        device = lengths.device if torch.is_tensor(lengths) else 'cpu'
-        lengths = lengths if torch.is_tensor(lengths) else torch.tensor(lengths)
-        max_length = max_length or torch.max(lengths)
-        start = torch.tensor(0).int()
-        indices = torch.arange(start=start, end=max_length, device=device)  # noqa
-        mask = indices.lt(lengths.view(-1, 1))
-
-        return mask
-
-    @staticmethod
-    def interleave(x, y):
-        """Interleave two tensors."""
-        xy = torch.stack([x[:-1], y], dim=1).view(-1)
-        xy = F.pad(xy, pad=[0, 1], value=x[-1])
-        return xy
-
-    def _collate_fn(self, batch):
-        batch = list(zip(*batch))
-
-        asr_batch = _speech_collate_fn(list(zip(*batch[:4])), pad_id=self.vocab.pad)
-        audio, audio_len, text, text_len = asr_batch
-
-        if self.blanking:
-            text = [
-                self.interleave(
-                    x=torch.empty(len(t) + 1, dtype=torch.long, device=t.device).fill_(self.vocab.blank), y=t,
-                )
-                for t in text
-            ]
-            text = self.merge(text, value=self.vocab.pad, dtype=torch.long)
-            text_len = text_len * 2 + 1
-
-        durs, f0 = batch[4:]
-        durs = self.merge(durs, dtype=torch.long)
-        f0_mask = self.make_mask([f.shape[-1] for f in f0])  # noqa
-        f0 = self.merge(f0, dtype=torch.float)
-
-        return (
-            audio,
-            audio_len,
-            text,
-            text_len,
-            durs,
-            f0,
-            f0_mask,
-        )
-
-
-@deprecated(version="1.8", explanation="Please, use ``nemo.tts.collections.torch.data.TTSDataset`` instead.")
-class AudioToCharWithPriorDataset(AudioToCharDataset):
-    """
-    Dataset that loads tensors via a json file containing paths to audio
-    files, transcripts, durations (in seconds).
-    Each new line is a different sample. Example below:
-    {"audio_filepath": "/path/to/audio_1.wav", "text": "the
-    transcription", "offset": 301.75, "duration": 0.82}
-    ...
-    {"audio_filepath": "/path/to/audio_n.wav", "text": "the
-    transcription", "offset": 301.75, "duration": 0.82}
-
-    Additionally, user provides path to folder with precomputed attention priors via "attn_prior_folder" arg.
-    This folder should contain saved numpy array as attention prior along mel and text lengths.
-    If folder is empty, attention priors will be calculated and saved in specified folder.
-    Every name of saved numpy array is a unique example identifier, which is a wav filename without suffix.
-
-    Args:
-        **kwargs: Passed to AudioToCharDataset constructor.
-        attn_prior_folder (str): String path to folder with precomputed attention priors.
-        n_window_stride (int): Stride of window for fft in samples. Need to generate prior.
-        vocab: Vocabulary config (parser + set of graphemes to use). Constructor propagates these to
-            `self.make_vocab` function call to build a complete vocabulary.
-    """
-
-    @property
-    def output_types(self) -> Optional[Dict[str, NeuralType]]:
-        """Returns definitions of module output ports."""
-        return {
-            'audio': NeuralType(('B', 'T'), AudioSignal()),
-            'audio_len': NeuralType(('B',), LengthsType()),
-            'text': NeuralType(('B', 'T'), LabelsType()),
-            'text_len': NeuralType(('B',), LengthsType()),
-            'attn_prior': NeuralType(('B', 'T', 'D'), ProbsType()),
-        }
-
-    def __init__(self, attn_prior_folder, n_window_stride=256, **kwargs):
-        self.vocab = AudioToCharWithDursF0Dataset.make_vocab(**kwargs.pop('vocab', {}))
-        kwargs.setdefault('labels', [])  # For compatibility.
-        super().__init__(**kwargs)
-
-        Path(attn_prior_folder).mkdir(parents=True, exist_ok=True)
-        self.attn_prior_folder = attn_prior_folder
-
-        self.n_window_stride = n_window_stride
-        self.id2enc_text = {}
-        for i, e in enumerate(self.manifest_processor.collection):
-            # cache vocab encoding
-            self.id2enc_text[i] = self.vocab.encode(e.text_raw)
-
-    @staticmethod
-    def beta_binomial_prior_distribution(phoneme_count, mel_count, scaling_factor=1.0):
-        x = np.arange(0, phoneme_count)
-        mel_text_probs = []
-        for i in range(1, mel_count + 1):
-            a, b = scaling_factor * i, scaling_factor * (mel_count + 1 - i)
-            mel_i_prob = betabinom(phoneme_count, a, b).pmf(x)
-            mel_text_probs.append(mel_i_prob)
-        return np.array(mel_text_probs)
-
-    def __getitem__(self, item):
-        audio, audio_len, _, _ = super().__getitem__(item)  # noqa
-
-        text = self.id2enc_text[item]
-
-        attn_prior_path = (
-            Path(self.attn_prior_folder)
-            / f"ap_tl{len(text)}_al_{math.ceil((audio_len.item() + 1) / self.n_window_stride)}.npy"
-        )
-
-        if attn_prior_path.exists():
-            attn_prior = np.load(attn_prior_path)
-        else:
-            attn_prior = self.beta_binomial_prior_distribution(
-                len(text), math.ceil((audio_len.item() + 1) / self.n_window_stride)
-            )
-            np.save(attn_prior_path, attn_prior)
-
-        text, text_len, attn_prior = (
-            torch.tensor(text).long(),
-            torch.tensor(len(text)).long(),
-            torch.tensor(attn_prior),
-        )
-
-        return audio, audio_len, text, text_len, attn_prior
-
-    def _collate_fn(self, batch):
-        batch = list(zip(*batch))
-
-        asr_batch = _speech_collate_fn(list(zip(*batch[:4])), pad_id=self.vocab.pad)
-        audio, audio_len, text, text_len = asr_batch
-        attn_prior_list = batch[4]
-
-        attn_prior = torch.zeros(
-            len(attn_prior_list),
-            max([attn_prior_i.shape[0] for attn_prior_i in attn_prior_list]),
-            max([attn_prior_i.shape[1] for attn_prior_i in attn_prior_list]),
-        )
-
-        for i, attn_prior_i in enumerate(attn_prior_list):
-            attn_prior[i, : attn_prior_i.shape[0], : attn_prior_i.shape[1]] = attn_prior_i
-
-        return audio, audio_len, text, text_len, attn_prior
-
-
-@deprecated(version="1.8", explanation="Please, use ``nemo.tts.collections.torch.data.TTSDataset`` instead.")
-class AudioToCharWithPriorAndPitchDataset(AudioToCharWithPriorDataset):
-    @property
-    def output_types(self) -> Optional[Dict[str, NeuralType]]:
-        """Returns definitions of module output ports."""
-        return {
-            'audio': NeuralType(('B', 'T'), AudioSignal()),
-            'audio_len': NeuralType(('B',), LengthsType()),
-            'text': NeuralType(('B', 'T'), LabelsType()),
-            'text_len': NeuralType(('B',), LengthsType()),
-            'attn_prior': NeuralType(('B', 'T', 'D'), ProbsType()),
-            'pitch': NeuralType(('B', 'T'), RegressionValuesType()),
-            'speakers': NeuralType(('B',), Index(), optional=True),
-        }
-
-    def __init__(self, sup_data_path, pitch_fmin, pitch_fmax, n_window_size, pitch_avg, pitch_std, **kwargs):
-        self.pitch_fmin = pitch_fmin
-        self.pitch_fmax = pitch_fmax
-        self.n_window_size = n_window_size
-        self.pitch_avg = pitch_avg
-        self.pitch_std = pitch_std
-        super().__init__(attn_prior_folder=sup_data_path, **kwargs)
-
-    def __getitem__(self, item):
-        audio, audio_len, text, text_len, attn_prior = super().__getitem__(item)
-        tag = Path(self.manifest_processor.collection[item].audio_file).stem
-        pitch_path = (
-            Path(self.attn_prior_folder)
-            / f"{tag}_pitch_pyin_fmin{self.pitch_fmin}_fmax{self.pitch_fmax}_fl{self.n_window_size}.npy"
-        )
-
-        if pitch_path.exists():
-            pitch = np.load(pitch_path)
-        else:
-            pitch, _, _ = librosa.pyin(
-                audio.numpy(),
-                fmin=self.pitch_fmin,
-                fmax=self.pitch_fmax,
-                frame_length=self.n_window_size,
-                sr=self.featurizer.sample_rate,
-                fill_na=0.0,
-            )
-            np.save(pitch_path, pitch)
-        pitch -= self.pitch_avg
-        pitch[pitch == -self.pitch_avg] = 0.0  # Zero out values that were perviously zero
-        pitch /= self.pitch_std
-
-        speaker = None
-        if self.manifest_processor.collection[item].speaker is not None:
-            speaker = torch.zeros_like(text_len).fill_(self.manifest_processor.collection[item].speaker)
-
-        return audio, audio_len, text, text_len, attn_prior, torch.tensor(pitch), speaker
-
-    def _collate_fn(self, batch):
-        batch = list(zip(*batch))
-        audio, audio_len, text, text_len, attn_prior = super()._collate_fn(list(zip(*batch[:5])))
-        pitch_list = batch[5]
-        speaker_list = batch[6]
-
-        pitch = torch.zeros(len(pitch_list), max([pitch.shape[0] for pitch in pitch_list]))
-
-        for i, pitch_i in enumerate(pitch_list):
-            pitch[i, : pitch_i.shape[0]] = pitch_i
-
-        speakers = []
-        for i, speaker_i in enumerate(speaker_list):
-            speakers.append(speaker_i)
-
-        speakers = torch.stack(speakers).to(text_len.dtype) if speakers[0] is not None else None
-
-        return audio, audio_len, text, text_len, attn_prior, pitch, speakers
-
-
-@deprecated(version="1.8", explanation="Please, use ``nemo.tts.collections.torch.data.TTSDataset`` instead.")
-class FastPitchDataset(_AudioTextDataset):
-    """
-    Dataset used for FastPitch that has both duration and pitch information per input char.
-    See https://github.com/NVIDIA/NeMo/pull/1799 for information on how to extract duration and pitch information.
-    """
-
-    @property
-    def output_types(self) -> Optional[Dict[str, NeuralType]]:
-        """Returns definitions of module output ports."""
-        return {
-            'audio': NeuralType(('B', 'T'), AudioSignal()),
-            'audio_len': NeuralType(('B',), LengthsType()),
-            'text': NeuralType(('B', 'T'), LabelsType()),
-            'text_len': NeuralType(('B',), LengthsType()),
-            'durs': NeuralType(('B', 'T'), TokenDurationType()),
-            'pitch': NeuralType(('B', 'T'), RegressionValuesType()),
-            'speakers': NeuralType(('B',), Index()),
-        }
-
-    def __getitem__(self, item):
-        audio, audio_len, text, text_len = super().__getitem__(item)  # noqa
-
-        audio_path = self.manifest_processor.collection[item].audio_file
-        durs_path = audio_path.replace('/wavs/', '/fastpitch/durations/').replace('.wav', '.pt')
-        pitch_path = audio_path.replace('/wavs/', '/fastpitch/pitch_char/').replace('.wav', '.pt')
-        speaker = None
-        if self.manifest_processor.collection[item].speaker is not None:
-            speaker = torch.zeros_like(text_len).fill_(self.manifest_processor.collection[item].speaker)
-
-        return (audio, audio_len, text, text_len, torch.load(durs_path), torch.load(pitch_path), speaker, audio_path)
-
-    def _collate_fn(self, batch):
-        pad_id = self.manifest_processor.pad_id
-        asr_batch = list(zip(*batch))[:4]
-        asr_batch = _speech_collate_fn(list(zip(*asr_batch)), pad_id=pad_id)
-        audio, audio_len, text, text_len = asr_batch
-
-        max_tokens_len = text.size(1)
-        durs, pitch, speakers = [], [], []
-        for _, _, _, tokens_i_len, durs_i, pitch_i, speaker_i, path_i in batch:
-            pad = (0, max_tokens_len - tokens_i_len.item())
-            assert len(durs_i) == len(pitch_i), f"{len(durs_i)}, {len(pitch_i)}: {path_i}"
-            assert len(durs_i) == tokens_i_len, f"{len(durs_i)}, {tokens_i_len}:  {path_i}"
-            durs.append(F.pad(durs_i, pad, value=pad_id))
-            pitch.append(F.pad(pitch_i, pad, value=pad_id))
-            speakers.append(speaker_i)
-
-        return (
-            audio,
-            audio_len,
-            text,
-            text_len,
-            torch.stack(durs).to(audio.dtype),
-            torch.stack(pitch).to(audio.dtype),
-            torch.stack(speakers).to(audio.dtype) if speakers[0] is not None else None,
-        )
-
-
 class AudioToBPEDataset(_AudioTextDataset):
     """
     Dataset that loads tensors via a json file containing paths to audio
