@@ -146,13 +146,6 @@ class AudioToMelSpectrogramPreprocessor(AudioPreprocessor):
             frame_splicing (int): Defaults to 1
             exact_pad (bool): If True, sets stft center to False and adds padding, such that num_frames = audio_length
                 // hop_length. Defaults to False.
-            stft_exact_pad (bool): If True, uses pytorch_stft and convolutions with
-                padding such that num_frames = num_samples / hop_length. If False,
-                stft_conv will be used to determine how stft will be performed.
-                Defaults to False. TODO:This feature is deprecated and will be removed in 1.1.0
-            stft_conv (bool): If True, uses pytorch_stft and convolutions. If
-                False, uses torch.stft. TODO:This feature is deprecated and will be removed in 1.1.0
-                Defaults to False
             pad_value (float): The value that shorter mels are padded with.
                 Defaults to 0
             mag_power (float): The power that the linear spectrogram is raised to
@@ -164,6 +157,8 @@ class AudioToMelSpectrogramPreprocessor(AudioPreprocessor):
                 Defaults to 0.0
             nb_max_freq (int) : Frequency above which all frequencies will be masked for narrowband augmentation.
                 Defaults to 4000
+            stft_exact_pad: Deprecated argument, kept for compatibility with older checkpoints.
+            stft_conv: Deprecated argument, kept for compatibility with older checkpoints.
         """
 
     def save_to(self, save_path: str):
@@ -220,13 +215,13 @@ class AudioToMelSpectrogramPreprocessor(AudioPreprocessor):
         pad_to=16,
         frame_splicing=1,
         exact_pad=False,
-        stft_exact_pad=False,
-        stft_conv=False,
         pad_value=0,
         mag_power=2.0,
         rng=None,
         nb_augmentation_prob=0.0,
         nb_max_freq=4000,
+        stft_exact_pad=False,  # Deprecated arguments; kept for config compatibility
+        stft_conv=False,  # Deprecated arguments; kept for config compatibility
     ):
         super().__init__(n_window_size, n_window_stride)
 
@@ -260,13 +255,13 @@ class AudioToMelSpectrogramPreprocessor(AudioPreprocessor):
             pad_to=pad_to,
             frame_splicing=frame_splicing,
             exact_pad=exact_pad,
-            stft_exact_pad=stft_exact_pad,
-            stft_conv=stft_conv,
             pad_value=pad_value,
             mag_power=mag_power,
             rng=rng,
             nb_augmentation_prob=nb_augmentation_prob,
             nb_max_freq=nb_max_freq,
+            stft_exact_pad=stft_exact_pad,  # Deprecated arguments; kept for config compatibility
+            stft_conv=stft_conv,  # Deprecated arguments; kept for config compatibility
         )
 
     def get_features(self, input_signal, length):
@@ -679,13 +674,13 @@ class AudioToMelSpectrogramPreprocessorConfig:
     pad_to: int = 16
     frame_splicing: int = 1
     exact_pad: bool = False
-    stft_exact_pad: bool = False
-    stft_conv: bool = False
     pad_value: int = 0
     mag_power: float = 2.0
     rng: Optional[str] = None
     nb_augmentation_prob: float = 0.0
     nb_max_freq: int = 4000
+    stft_exact_pad: bool = False  # Deprecated argument, kept for compatibility with older checkpoints.
+    stft_conv: bool = False  # Deprecated argument, kept for compatibility with older checkpoints.
 
 
 @dataclass
