@@ -102,9 +102,6 @@ class GPTModel(MegatronModule):
         persist_layer_norm=False,
         openai_gelu=False,
         onnx_safe=False,
-        use_soft_prompts=False,
-        num_prompt_tokens=10,
-        existing_prompt_tags=None,
     ):
 
         super(GPTModel, self).__init__()
@@ -148,9 +145,6 @@ class GPTModel(MegatronModule):
             persist_layer_norm=persist_layer_norm,
             openai_gelu=openai_gelu,
             onnx_safe=onnx_safe,
-            use_soft_prompts=use_soft_prompts,
-            num_prompt_tokens=num_prompt_tokens,
-            existing_prompt_tags=existing_prompt_tags,
         )
 
         self.initialize_word_embeddings(
@@ -167,7 +161,6 @@ class GPTModel(MegatronModule):
         position_ids,
         attention_mask,
         labels=None,
-        prompt_ids=None,
         token_type_ids=None,
         layer_past=None,
         get_key_value=False,
@@ -181,7 +174,6 @@ class GPTModel(MegatronModule):
             input_ids,
             position_ids,
             attention_mask,
-            prompt_ids=prompt_ids,
             layer_past=layer_past,
             get_key_value=get_key_value,
             encoder_input=encoder_input,
@@ -225,9 +217,3 @@ class GPTModel(MegatronModule):
         if self._language_model_key in state_dict:
             state_dict = state_dict[self._language_model_key]
         self.language_model.load_state_dict(state_dict, strict=strict)
-
-    def _init_prompt_from_random(self, prompt_tag, prompt_id):
-        self.language_model._init_prompt_from_random(prompt_tag, prompt_id)
-
-    def _init_prompt_from_text(self, prompt_tag, prompt_id, init_token_ids):
-        self.language_model._init_prompt_from_text(prompt_tag, prompt_id, init_token_ids)
