@@ -171,9 +171,14 @@ class MegatronLMEncoderDecoderModel(MegatronBaseModel):
             layernorm_epsilon=self.cfg.get('layernorm_epsilon', 1e-5),
             persist_layer_norm=self.cfg.get('persist_layer_norm', False),
             bias_gelu_fusion=self.cfg.get('bias_gelu_fusion', True),
+            bias_dropout_add_fusion=self.cfg.get('bias_dropout_add_fusion', True),
             masked_softmax_fusion=self.cfg.get('masked_softmax_fusion', True),
             onnx_safe=self.cfg.get('onnx_safe', False),
             activation=self.cfg.get('activation', 'gelu'),
+            bias=self.cfg.get('bias', True),
+            normalization=self.cfg.get('normalization', 'layernorm'),
+            transformer_block_type=self.cfg.get('transformer_block_type', 'pre_ln'),
+            headscale=self.cfg.get('headscale', False),
             add_encoder=add_encoder,
             add_decoder=add_decoder,
         )
