@@ -32,14 +32,43 @@ class MegatronT5Model(MegatronLMEncoderDecoderModel):
     def __init__(self, cfg: DictConfig, trainer: Trainer):
         super().__init__(cfg, trainer=trainer)
 
+        # validate cfg
+        self._validate_cfg()
+
+    @property
+    def model_name(self):
+        """Allows child classes to implement models with different data regime"""
+        return "T5"
+
+    def _validate_cfg(self):
+        """Class-specific cfg validation"""
+        # Make sure the user specifies dataset type as either 't5' or 't5_prefix_lm' only.
+        if self._cfg.data.get('dataset_type', None) is not None:
+            if self._cfg.data.get('dataset_type') not in ['t5', 't5_prefix_lm']:
+                raise ValueError(
+                    f"dataset_type must be either 't5' or 't5_prefix_lm'. found {self._cfg.data.get('dataset_type')}"
+                )
+
+        if hasattr(self._cfg.data, 'seq_length_dec') and self._cfg.data.get('dataset_type') == 't5':
+            if self._cfg.data.seq_length_dec < self._cfg.data.seq_length * self._cfg.data.masked_lm_prob:
+                raise ValueError(
+                    f"Cannot have decoder max sequence length ({self._cfg.data.seq_length_dec}) less than encoder sequence length ({self._cfg.data.seq_length}) * masked_lm_prob ({self._cfg.data.masked_lm_prob})"
+                )
+
+    @property
+    def _build_train_valid_test_datasets_kwargs(self):
+        """allows child classes to add kwargs to dataset building"""
+        return dict(max_seq_length_dec=self._cfg.data.seq_length_dec,)
+
     def _build_vocab(self):
-        # T5-related construction
-        self.num_sentinel_tokens = self._cfg.tokenizer.num_sentinel_tokens
         self._add_special_tokens_to_tokenizer()
 
         super()._build_vocab()
 
     def _add_special_tokens_to_tokenizer(self):
+        # T5-related construction
+        self.num_sentinel_tokens = self._cfg.tokenizer.num_sentinel_tokens
+
         if self._cfg.tokenizer.library == 'huggingface' or self._cfg.tokenizer.library == 'megatron':
             additional_tokens = {
                 'additional_special_tokens': [f'<extra_id_{i}>' for i in range(self.num_sentinel_tokens)]
@@ -91,12 +120,8 @@ class MegatronT5Model(MegatronLMEncoderDecoderModel):
                     self.tokenizer.add_special_tokens([f'<extra_id_{i}>'])
 
     def build_train_valid_test_datasets(self):
-        logging.info('Building T5 datasets.')
-        if self._cfg.data.seq_length_dec < self._cfg.data.seq_length * self._cfg.data.masked_lm_prob:
-            raise ValueError(
-                f"Cannot have decoder max sequence length ({self._cfg.data.seq_length_dec}) less than encoder sequence length ({self._cfg.data.seq_length}) * masked_lm_prob ({self._cfg.data.masked_lm_prob})"
-            )
-        global_batch_size = self.trainer.world_size * self._cfg.micro_batch_size / self._cfg.tensor_model_parallel_size
+        logging.info(f'Building {self.model_name} datasets.')
+        global_batch_size = self._cfg.global_batch_size
         eval_iters = (self.trainer.max_steps // self.trainer.val_check_interval + 1) * self.trainer.limit_val_batches
         test_iters = self.trainer.limit_test_batches
         train_valid_test_num_samples = [
@@ -104,12 +129,6 @@ class MegatronT5Model(MegatronLMEncoderDecoderModel):
             eval_iters * global_batch_size,
             test_iters * global_batch_size,
         ]
-        # Make sure the user specifies dataset type as either 't5' or 't5_prefix_lm' only.
-        if self._cfg.data.get('dataset_type', None) is not None:
-            if self._cfg.data.get('dataset_type') not in ['t5', 't5_prefix_lm']:
-                raise ValueError(
-                    f"dataset_type must be either 't5' or 't5_prefix_lm'. found {self._cfg.data.get('dataset_type')}"
-                )
         self._train_ds, self._validation_ds, self._test_ds = build_train_valid_test_datasets(
             cfg=self._cfg,
             trainer=self.trainer,
@@ -119,23 +138,24 @@ class MegatronT5Model(MegatronLMEncoderDecoderModel):
             splits_string=self._cfg.data.splits_string,
             train_valid_test_num_samples=train_valid_test_num_samples,
             max_seq_length=self._cfg.data.seq_length,
-            max_seq_length_dec=self._cfg.data.seq_length_dec,
             masked_lm_prob=self._cfg.data.masked_lm_prob,
             short_seq_prob=self._cfg.data.short_seq_prob,
             seed=self._cfg.seed,
             skip_warmup=self._cfg.data.skip_warmup,
-            dataset_type=self._cfg.data.get('dataset_type', 't5'),
+            dataset_type=self._cfg.data.get('dataset_type', self.model_name.lower()),
             max_ngram_size=self._cfg.data.get('max_ngram_size', 10),
             mean_ngram_size=self._cfg.data.get('mean_ngram_size', None),
             geometric_dist=self._cfg.data.get('geometric_dist', True),
             permutation=self._cfg.data.get('permutation', False),
             whole_word_masking=self._cfg.data.get('whole_word_masking', True),
             favor_long_ngrams=self._cfg.data.get('favor_long_ngrams', False),
+            # additional arguments from child classes
+            **self._build_train_valid_test_datasets_kwargs,
         )
         logging.info(f'Length of train dataset: {len(self._train_ds)}')
         logging.info(f'Length of val dataset: {len(self._validation_ds)}')
         logging.info(f'Length of test dataset: {len(self._test_ds)}')
-        logging.info(f'Finished building T5 datasets.')
+        logging.info(f'Finished building {self.model_name} datasets.')
         return self._train_ds, self._validation_ds, self._test_ds
 
     def list_available_models(self):
