@@ -19,6 +19,8 @@ from nemo.collections.nlp.modules.common import (
     BertModule,
     CamembertEncoder,
     DistilBertEncoder,
+    PromptEncoder,
+    PromptTable,
     RobertaEncoder,
     SequenceClassifier,
     SequenceRegression,
