@@ -1,5 +1,4 @@
 # Copyright (c) 2021, NVIDIA CORPORATION.  All rights reserved.
-# Copyright 2015 and onwards Google, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -44,8 +43,6 @@ class AbbreviationFst(GraphFst):
         graph = NEMO_UPPER + dot + pynini.closure(insert_space + NEMO_UPPER + dot, 1)
         # A.B.C. -> A.B.C.
         graph |= NEMO_UPPER + dot + pynini.closure(NEMO_UPPER + dot, 1)
-        # ABC -> ABC
-        graph |= NEMO_UPPER + pynini.closure(NEMO_UPPER, 1)
         # ABC -> A B C
         graph |= NEMO_UPPER + pynini.closure(insert_space + NEMO_UPPER, 1)
 
