@@ -1,5 +1,4 @@
 # Copyright (c) 2021, NVIDIA CORPORATION.  All rights reserved.
-# Copyright 2015 and onwards Google, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -73,10 +72,10 @@ class VerbalizeFst(GraphFst):
             | whitelist_graph
         )
 
-        if not deterministic:
-            roman_graph = RomanFst(deterministic=deterministic).fst
-            graph |= roman_graph
+        # roman_graph = RomanFst(deterministic=deterministic).fst
+        # graph |= roman_graph
 
+        if not deterministic:
             abbreviation_graph = AbbreviationFst(deterministic=deterministic).fst
             graph |= abbreviation_graph
 
